"use strict";

require("core-js/modules/es.object.define-property.js");
require("core-js/modules/es.object.keys.js");
require("core-js/modules/es.array.filter.js");
require("core-js/modules/es.object.get-own-property-descriptor.js");
require("core-js/modules/es.array.for-each.js");
require("core-js/modules/web.dom-collections.for-each.js");
require("core-js/modules/es.object.get-own-property-descriptors.js");
require("core-js/modules/es.object.define-properties.js");
require("core-js/modules/es.symbol.iterator.js");
require("core-js/modules/es.array.iterator.js");
require("core-js/modules/es.string.iterator.js");
require("core-js/modules/web.dom-collections.iterator.js");
require("core-js/modules/es.symbol.to-primitive.js");
require("core-js/modules/es.date.to-primitive.js");
require("core-js/modules/es.symbol.js");
require("core-js/modules/es.symbol.description.js");
require("core-js/modules/es.object.to-string.js");
require("core-js/modules/es.number.constructor.js");
var _sinon = require("sinon");
var _chai = require("chai");
var _Formio = require("./Formio");
var _FormBuilder = _interopRequireDefault(require("./FormBuilder"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { "default": e }; }
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
describe('PDF Builder tests', function () {
  describe('PDF Auto Conversion', function () {
    var originalUploadFile = _Formio.GlobalFormio.prototype.uploadFile;
    var originalLoadProject = _Formio.GlobalFormio.prototype.loadProject;
    after(function () {
      _Formio.GlobalFormio.prototype.uploadFile = originalUploadFile;
      _Formio.GlobalFormio.prototype.loadProject = originalLoadProject;
    });
    beforeEach(function () {
      _Formio.GlobalFormio.prototype.loadProject = _sinon.fake.resolves(null);
    });
    var getUploadResponseMock = function getUploadResponseMock(withNonFillable) {
      return {
        data: {
          file: 'fileId',
          filesServer: 'http://fakeserver.test',
          path: '/path/to/pdf/file',
          formfields: _objectSpread({
            components: [{
              input: true,
              label: 'Test',
              key: 'testTextField',
              type: 'textfield',
              overlay: {
                top: 135,
                left: 211.516,
                height: 20,
                width: 100,
                page: 1
              }
            }]
          }, withNonFillable && {
            nonFillableConversionUsed: true
          })
        }
      };
    };
    it('Should assign fields from PDF auto conversion to the empty form', function (done) {
      var uploadResponseMock = getUploadResponseMock();
      _Formio.GlobalFormio.prototype.uploadFile = _sinon.fake.resolves(uploadResponseMock);
      var form = {
        type: 'form',
        components: [],
        display: 'pdf',
        name: 'testPdfForm'
      };
      var builder = new _FormBuilder["default"](document.createElement('div'), form, {});
      builder.ready.then(function (builder) {
        builder.on('pdfUploaded', function (result) {
          (0, _chai.expect)(result).to.be.deep.equal(uploadResponseMock.data);
          (0, _chai.expect)(builder.webform.form.components).to.be.deep.equal(uploadResponseMock.data.formfields.components);
          (0, _chai.expect)(builder.webform.form.settings.pdf.nonFillableConversionUsed).to.be.undefined;
          done();
        });
        builder.upload();
      });
    });
    it('Should assign fields from PDF auto conversion to the initial form', function (done) {
      var uploadResponseMock = getUploadResponseMock();
      _Formio.GlobalFormio.prototype.uploadFile = _sinon.fake.resolves(uploadResponseMock);
      var form = {
        type: 'form',
        components: [{
          input: true,
          label: 'Submit',
          key: 'submit',
          action: 'submit',
          type: 'button'
        }],
        display: 'pdf',
        name: 'testPdfForm'
      };
      var builder = new _FormBuilder["default"](document.createElement('div'), form, {});
      builder.ready.then(function (builder) {
        builder.on('pdfUploaded', function (result) {
          (0, _chai.expect)(result).to.be.deep.equal(uploadResponseMock.data);
          (0, _chai.expect)(builder.webform.form.components).to.be.deep.equal(uploadResponseMock.data.formfields.components);
          (0, _chai.expect)(builder.webform.form.settings.pdf.nonFillableConversionUsed).to.be.undefined;
          done();
        });
        builder.upload();
      });
    });
    it('Should assign fields from PDF non fillable conversion to the initial form', function (done) {
      var uploadResponseMock = getUploadResponseMock(true);
      _Formio.GlobalFormio.prototype.uploadFile = _sinon.fake.resolves(uploadResponseMock);
      var form = {
        type: 'form',
        components: [{
          input: true,
          label: 'Submit',
          key: 'submit',
          action: 'submit',
          type: 'button'
        }],
        display: 'pdf',
        name: 'testPdfForm'
      };
      var builder = new _FormBuilder["default"](document.createElement('div'), form, {});
      builder.ready.then(function (builder) {
        builder.on('pdfUploaded', function (result) {
          (0, _chai.expect)(result).to.be.deep.equal(uploadResponseMock.data);
          (0, _chai.expect)(builder.webform.form.components).to.be.deep.equal(uploadResponseMock.data.formfields.components);
          (0, _chai.expect)(builder.webform.form.settings.pdf.nonFillableConversionUsed).to.be["true"];
          done();
        });
        builder.upload();
      });
    });
    it('Should not assign fields from PDF auto conversion to non pristine form', function (done) {
      var uploadResponseMock = getUploadResponseMock(true);
      _Formio.GlobalFormio.prototype.uploadFile = _sinon.fake.resolves(uploadResponseMock);
      var form = {
        type: 'form',
        components: [{
          input: true,
          label: 'Text Field',
          key: 'textField',
          type: 'textfield',
          overlay: {
            top: 135,
            left: 211.516,
            height: 20,
            width: 100,
            page: 1
          }
        }, {
          input: true,
          label: 'Submit',
          key: 'submit',
          action: 'submit',
          type: 'button'
        }],
        display: 'pdf',
        name: 'testPdfForm'
      };
      var builder = new _FormBuilder["default"](document.createElement('div'), form, {});
      builder.ready.then(function (builder) {
        builder.on('pdfUploaded', function (result) {
          (0, _chai.expect)(result).to.be.deep.equal(uploadResponseMock.data);
          (0, _chai.expect)(builder.webform.form.components).to.be.deep.equal(form.components);
          (0, _chai.expect)(builder.webform.form.settings.pdf.nonFillableConversionUsed).to.be["false"];
          done();
        });
        builder.upload();
      });
    });
  });
});